==> nextcloud-app-deck-1%3A1.2.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/deck/l10n/es_AR.js <==
OC.L10N.register(
    "deck",
    {
    "Deck" : "Deck",
    "Personal" : "Personal",
    "Finished" : "Terminado",
    "To review" : "Para revisar",
    "Action needed" : "Acción requerida",
    "Later" : "Después",
    "copy" : "copiar",
    "Done" : "Hecho",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "El archivo subido sobrepasa el valor MAX_FILE_SIZE especificada en el formulario HTML",
    "No file was uploaded" : "No se subió ningún archivo ",
    "Missing a temporary folder" : "Falta un directorio temporal",
    "Cancel" : "Cancelar",
    "Hide archived cards" : "Ocultar tarjetas archivadas",
    "Show archived cards" : "Mostrar tarjetas archivadas",
    "Details" : "Detalles",
    "Sharing" : "Compartiendo",
    "Tags" : "Etiquetas",
    "Undo" : "Deshacer",
    "Can edit" : "Puede editar",
    "Can share" : "Puede compartir",
    "Delete" : "Eliminar",
    "Edit" : "Editar",
    "Members" : "Miembros",
    "Attachments" : "Adjuntos",
    "Comments" : "Comentarios",
    "Modified" : "Modificado",
    "Created" : "Creado",
    "Due date" : "Fecha de vencimiento",
    "Select Date" : "Seleccionar fecha",
    "Save" : "Guardar",
    "Reply" : "Responder",
    "Update" : "Actualizar",
    "Description" : "Descripción",
    "Formatting help" : "Ayuda de formato",
    "(group)" : "(grupo)",
    "seconds ago" : "segundos",
    "Shared with you" : "Compartido con usted",
    "Board details" : "Detalles del tablero",
    "An error occurred" : "Ocurrió un error",
    "Today" : "Hoy",
    "Tomorrow" : "Mañana",
    "This week" : "Esta semana"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-deck-1%3A1.6.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/deck/l10n/es_AR.js <==
OC.L10N.register(
    "deck",
    {
    "Deck" : "Deck",
    "Personal" : "Personal",
    "Finished" : "Terminado",
    "To review" : "Para revisar",
    "Action needed" : "Acción requerida",
    "Later" : "Después",
    "copy" : "copiar",
    "Done" : "Hecho",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "El archivo subido sobrepasa el valor MAX_FILE_SIZE especificada en el formulario HTML",
    "No file was uploaded" : "No se subió ningún archivo ",
    "Missing a temporary folder" : "Falta un directorio temporal",
    "Invalid date, date format must be YYYY-MM-DD" : "La fecha es inválida, favor de seguir el formato AAAA-MM-DD",
    "Add board" : "Nuevo Tablero",
    "Cancel" : "Cancelar",
    "Close" : "Cerrar",
    "Hide archived cards" : "Ocultar tarjetas archivadas",
    "Show archived cards" : "Mostrar tarjetas archivadas",
    "Details" : "Detalles",
    "Sharing" : "Compartiendo",
    "Tags" : "Etiquetas",
    "Undo" : "Deshacer",
    "Can edit" : "Puede editar",
    "Can share" : "Puede compartir",
    "Owner" : "Dueño",
    "Delete" : "Eliminar",
    "Edit" : "Editar",
    "Members" : "Miembros",
    "Download" : "Descargar",
    "Attachments" : "Adjuntos",
    "Comments" : "Comentarios",
    "Modified" : "Modificado",
    "Created" : "Creado",
    "Due date" : "Fecha de vencimiento",
    "Select Date" : "Seleccionar fecha",
    "Today" : "Hoy",
    "Tomorrow" : "Mañana",
    "Next week" : "Proxima semana",
    "Next month" : "Proximo mes",
    "Save" : "Guardar",
    "Reply" : "Responder",
    "Update" : "Actualizar",
    "Description" : "Descripción",
    "Formatting help" : "Ayuda de formato",
    "(group)" : "(grupo)",
    "seconds ago" : "segundos",
    "All boards" : "Todos los Tableros",
    "Shared with you" : "Compartido con usted",
    "Board details" : "Detalles del tablero",
    "Edit board" : "Editar Tablero",
    "Clone board" : "Clonar Tablero",
    "No notifications" : "No hay notificaciones",
    "Delete board" : "Eliminar Tablero",
    "An error occurred" : "Ocurrió un error",
    "Share" : "Compartir",
    "This week" : "Esta semana"
},
"nplurals=2; plural=(n != 1);");
